/*	Blunder Delay
	A Thunderbird Extension to automatically flush the Unsent Messages folder
	at regular intervals.

	By Andrew C. Brown
	http://bananabread.net

	ChangeLog:

	0.5.0	Delay can now be set by seconds, minutes or hours. Also added
			default pref settings.
	0.4.5	Preferences now apply immediately
	0.4.0	Added a "Recall" command which deletes a message from the queue
			while simultaneously editing it as new.
	0.3.1	Change variables c, timer and observe to avoid namespace conflicts
	0.3.0	Add localization file
	0.2.0	Preferences functional
	0.1.0	First released code.
		Shortcoming: Only operates when main window is visible.
		Preferences aren't yet functional.
*/

var BlunderDelay_observer = {
  // Components.interfaces.nsIObserver
  observe: function(aSubject, aTopic, aData)
  {
	goDoCommand('cmd_sendUnsentMsgs')
  },

  QueryInterface : function(iid)
  {
	if ( iid.equals(Components.interfaces.nsIObserver) || 
		iid.equals(Components.interfaces.nsISupportsWeakReference) ||
		iid.equals(Components.interfaces.nsISupports)
	)
	return this;
	throw Components.results.NS_NOINTERFACE;
  }
};


var BlunderDelay_c, BlunderDelay_timer;


function initBlunderDelay()
{
	OnLoadMessenger(); // Making up for overriding it in the messenger.xul
	myPrefObserver.register();
	
	BlunderDelay_c = Components.classes["@mozilla.org/timer;1"];
	BlunderDelay_timer = BlunderDelay_c.createInstance(Components.interfaces.nsITimer);
	
	initBlunderSendTimer();
}

function initBlunderSendTimer()
{
    var prefService = Components.classes["@mozilla.org/preferences-service;1"]
                                .getService(Components.interfaces.nsIPrefService);
	var blunder_branch = prefService.getBranch("extensions.blunderdelay.");
	
	var enabled = blunder_branch.getBoolPref("enable");
	if (enabled)
	{
		var interval = blunder_branch.getIntPref("interval");
		var units = blunder_branch.getIntPref("units");

		var milliseconds = Math.max(5000,Math.round(interval * units * 1000));
		// Minumum is hereby set to 5000ms = 5s

		BlunderDelay_timer.init(BlunderDelay_observer,  milliseconds, BlunderDelay_timer.TYPE_REPEATING_SLACK);
	}
}



var myPrefObserver =
{
  register: function()
  {
    var prefService = Components.classes["@mozilla.org/preferences-service;1"]
                                .getService(Components.interfaces.nsIPrefService);
    this._branch = prefService.getBranch("extensions.blunderdelay.");
    this._branch.QueryInterface(Components.interfaces.nsIPrefBranch2);
    this._branch.addObserver("", this, false);
  },

  unregister: function()
  {
    if(!this._branch) return;
    this._branch.removeObserver("", this);
  },

  observe: function(aSubject, aTopic, aData)
  {
    if(aTopic != "nsPref:changed") return;

    BlunderDelay_timer.cancel()
    initBlunderSendTimer();

  }
}


